<!-- DOC_TYPE: API -->

# Cabinet Internal Modules

This section contains the lower-level cabinet registry, dashboard providers, Redis managers, view helpers, and model support classes.

## Registry

::: codex_django.cabinet.registry

## Types

::: codex_django.cabinet.types

## Context processors

::: codex_django.cabinet.context_processors

## Dashboard selector

::: codex_django.cabinet.selector.dashboard

## Dashboard Redis manager

::: codex_django.cabinet.redis.managers.dashboard

## Settings Redis manager

::: codex_django.cabinet.redis.managers.settings

## Settings model

::: codex_django.cabinet.models.settings

## Shared model mixins

::: codex_django.cabinet.models.mixins

## Dashboard views

::: codex_django.cabinet.views.dashboard

## Site settings views

::: codex_django.cabinet.views.site_settings
